/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief Example project on GPIO usage to drive LEDs
* @defgroup gpio_example GPIO example
* @{
* @ingroup nrf_examples_nrf6310
*
* @brief Example of GPIO output usage.
*
* This example shows how to configure GPIO pins as outputs which can also be used to drive LEDs.
* Each LED is set on one at a time and each state lasts 100 milliseconds.
* @image html example_board_setup_a.png "Use setup A when using the nrf6310 board for this example."
*/

#include <stdbool.h>
#include <stdint.h>
#include "nrf_delay.h"
#include "nrf_gpio.h"
#include "boards.h"

static uint8_t result = 0;

void adc_conf(void);

/**
 * main() function
 * @return 0. int return type required by ANSI/ISO standard.
 */
int main(void)
{
  adc_conf();	
  while(true)
  {
    // Wait for interrupt
    __WFI();
    // When interrupt is done, read result for debugging purpose
    result = result;
  }
}

void ADC_IRQHandler(void)
{
	if (NRF_ADC->EVENTS_END != 0)
	{
		NRF_ADC->EVENTS_END = 0;
		result = NRF_ADC->RESULT;
		NRF_ADC->TASKS_STOP = 1;
		NRF_ADC->TASKS_START = 1;
	}
}

void adc_conf(void)
{
    // Configure ADC
    NRF_ADC->INTENSET   = ADC_INTENSET_END_Msk;
    NRF_ADC->CONFIG     = (ADC_CONFIG_RES_8bit << ADC_CONFIG_RES_Pos) |
                          (ADC_CONFIG_INPSEL_AnalogInputOneThirdPrescaling << ADC_CONFIG_INPSEL_Pos) |
                          (ADC_CONFIG_REFSEL_SupplyOneHalfPrescaling << ADC_CONFIG_REFSEL_Pos) |
                          (ADC_CONFIG_PSEL_AnalogInput5 << ADC_CONFIG_PSEL_Pos) |
                          (ADC_CONFIG_EXTREFSEL_AnalogReference0 << ADC_CONFIG_EXTREFSEL_Pos);
    NRF_ADC->EVENTS_END = 0;
    NRF_ADC->ENABLE     = 1;
    NRF_ADC->TASKS_START = 1;
    // Enable ADC interrupt    
	NVIC_ClearPendingIRQ(ADC_IRQn);    		
    NVIC_EnableIRQ(ADC_IRQn);
}

/**
 *@}
 **/
